@@ -1,3 +1,20 @@
+/*  This file is part of corebird, a Gtk+ linux Twitter client.
+ *  Copyright (C) 2016 Timm Bäder
+ *
+ *  corebird is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  corebird is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with corebird.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #ifndef MEDIA_H
 #define MEDIA_H
 
@@ -9,7 +26,6 @@ G_BEGIN_DECLS
 
 typedef enum {
   CB_MEDIA_TYPE_IMAGE,
-  CB_MEDIA_TYPE_VINE,
   CB_MEDIA_TYPE_GIF,
   CB_MEDIA_TYPE_ANIMATED_GIF,
   CB_MEDIA_TYPE_TWITTER_VIDEO,
